<?php

class BinOptIn
{
	function __construct()
	{
		// translation
		add_action('init', [$this, 'load_textdomain']);
		
		// add styles/scripts
		add_action('admin_enqueue_scripts', [$this, 'admin_enqueue_scripts']);
		add_action('wp_enqueue_scripts', [$this, 'enqueue_scripts']);
		
		// custompages
		add_action('init', [$this, 'init_custompages']);
		add_filter('query_vars', [$this, 'query_vars_custompages']);
		add_action('parse_request', [$this, 'parse_request_custompages']);
		
		// dependency check
		add_action('wp_ajax_bin_opt_in_admin_notice_dismiss', [$this, 'wp_ajax_bin_opt_in_admin_notice_dismiss']);
		if(get_option('bin_opt_in_dependency_check') === 'enabled') { add_action('admin_notices', [$this, 'admin_notice']); }
	}
	
	/**
	 * load textdomain
	 */
	function load_textdomain()
	{
		// vars
		$domain = 'bin-opt-in';
		$locale = is_admin() && function_exists('get_user_locale') ? get_user_locale() : get_locale();
		$mofile = $domain.'-'.$locale.'.mo';

		// load from the languages directory first
		load_textdomain($domain, WP_LANG_DIR.'/plugins/'.$mofile);

		// redirect missing translations
		$mofile = str_replace('de_DE', 'de_CH', $mofile);

		// load from plugin lang folder
		$loaded = load_textdomain($domain, BIN_OPT_IN_DIR.'/languages/'.$mofile);
	}
	
	/**
	 * Add admin style/script
	 */
	function admin_enqueue_scripts()
	{
		wp_enqueue_style('bin-opt-in-back', BIN_OPT_IN_URL.'/css/back.css', ['wp-color-picker'], BIN_OPT_IN_VERSION);
		wp_enqueue_script('bin-opt-in-back', BIN_OPT_IN_URL.'/js/back.js', ['wp-color-picker'], BIN_OPT_IN_VERSION, true);
	}
	
	/**
	 * Add frontend style/script
	 */
	function enqueue_scripts()
	{
		wp_enqueue_style('bin-opt-in-front', BIN_OPT_IN_URL.'/css/front.css', false, BIN_OPT_IN_VERSION);
	}
	
	/**
	 * Add dependency check message
	 */
	function admin_notice()
	{
		$checkPlugins = [
			'bin-opt-in' => [
				'name' => 'Bin Contact',
				'path' => 'bin-contact/bin-contact.php',
				'text_activate' => __('The plugin <strong>%s</strong> is recommended to store your contacts in an effective manner.', 'bin-opt-in')
			]
		];

		$installedPlugins = get_plugins();

		$sitewidePlugins = [];
		if(is_array(get_site_option('active_sitewide_plugins'))) { $sitewidePlugins = get_site_option('active_sitewide_plugins'); }
		$plugins = array_merge(array_flip(get_option('active_plugins')), $sitewidePlugins);

		$message = '';
		foreach($checkPlugins as $checkPluginName => $checkPluginInfo)
		{
			if(!array_key_exists($checkPluginInfo['path'], $plugins))
			{
				if(isset($installedPlugins[$checkPluginInfo['path']]))
				{
					$message .= '<p>'.sprintf($checkPluginInfo['text_activate'], $checkPluginInfo['name']).' <a class="button" href="'.self_admin_url('plugins.php').'">'.__('Activate', 'bin-opt-in').'</a></p>';
				}
				else
				{
					$url = add_query_arg(['action' => 'install-plugin', 'plugin' => $checkPluginName], self_admin_url('update.php'));
					$message .= '<p>'.sprintf($checkPluginInfo['text_activate'], $checkPluginInfo['name']).' <a class="button" href="'.wp_nonce_url($url, 'install-plugin_'.$checkPluginName).'">'.__('Install', 'bin-opt-in').'</a></p>';
				}
			}
		}

		if(!empty($message))
		{
			echo '<div id="bin_opt_in_admin_notice" class="notice notice-error">';
				echo '<p><strong>'.sprintf(__('%s dependency check failed', 'bin-opt-in'), 'Bin Opt-in').'</strong></p>';
				echo '<div class="bin_opt_in_admin_notice_message">'.$message.'</div>';
				echo '<p><a href="admin.php?page=bin_opt_in_option_setting" class="bin_opt_in_admin_notice_dismiss">'.__('Disable notice', 'bin-opt-in').'</a></p>';
			echo '</div>';
		}
	}
	
	/**
	 * set dependency check disabled
	 */
	function wp_ajax_bin_opt_in_admin_notice_dismiss()
	{
		update_option('bin_opt_in_dependency_check', 'disabled');
		wp_die();
	}
	
	/**
	 * Add custom pages
	 */
	public static function init_custompages()
	{
		add_rewrite_rule('^opt-in/confirm', 'index.php?bin-opt-in-custompage=confirm', 'top');
	}

	/**
	 * Add custom pages to query vars
	 * @param array $query_vars
	 * @return string
	 */
	public static function query_vars_custompages($query_vars)
	{
		$query_vars[] = 'bin-opt-in-custompage';
		return $query_vars;
	}

	// load custom page
	public static function parse_request_custompages(&$wp)
	{
		if(isset($wp->query_vars['bin-opt-in-custompage']) && $wp->query_vars['bin-opt-in-custompage'] === 'confirm')
		{
			require_once BIN_OPT_IN_DIR.'/custompages/confirm.php';
			exit();
		}
	}
	
	public static function optIn($postdata, $options)
	{
		$opt_in_admin_message = ($options['opt_in_admin_message'] === true) ? true : false;
		$double_opt_in = ($options['double_opt_in'] === true) ? true : false;
		$admin_unlock = ($options['admin_unlock'] === true) ? true : false;
		$unlock_message = ($options['unlock_message'] === true) ? true : false;
		
		$post_id = '';
		if(class_exists('BinContact'))
		{
			$post_id = self::saveContact($postdata, $opt_in_admin_message, $double_opt_in, $admin_unlock, $unlock_message);	
		}
		
		// send messages 
		self::sendMessages($postdata, $opt_in_admin_message, $double_opt_in, $admin_unlock, $unlock_message);
		
		// wp super cache: clear cache
		if(function_exists('wp_cache_clear_cache')) { wp_cache_clear_cache(); }
	}
	
	public static function saveContact($postdata, $opt_in_admin_message, $double_opt_in, $admin_unlock, $unlock_message)
	{
		global $wpdb;
		
		$bin_opt_in_contact = 'registered';
		if($double_opt_in === true) { $bin_opt_in_contact = 'confirming'; }
		else if($admin_unlock === true) { $bin_opt_in_contact = 'pending'; }
		
		// search for contact by email
		$table_name = $wpdb->prefix."postmeta";
		$contact = $wpdb->get_results("SELECT * FROM $table_name where meta_key = 'bin_contact_email' AND  meta_value = '".sanitize_email($postdata['email'])."' limit 1");

		$post_id = '';
		
		// update if contact already exists
		if(isset($contact[0]->post_id) && is_email($postdata['email']))
		{
			$post_id = $contact[0]->post_id;
			$contactMeta = get_post_meta($post_id);

			if(empty($contactMeta['bin_contact_salutation'][0]))
			{
				update_post_meta($post_id, 'bin_contact_salutation', sanitize_text_field($postdata['salutation']));
			}

			if(empty($contactMeta['bin_contact_polite_form'][0]))
			{
				update_post_meta($post_id, 'bin_contact_polite_form', sanitize_text_field($postdata['polite_form']));
			}

			if(empty($contactMeta['bin_contact_language_of_correspondence'][0]))
			{
				update_post_meta($post_id, 'bin_contact_language_of_correspondence', sanitize_text_field($postdata['language_of_correspondence']));
			}

			if(empty($contactMeta['bin_contact_name_suffix'][0]))
			{
				update_post_meta($post_id, 'bin_contact_name_suffix', sanitize_text_field($postdata['name_suffix']));
			}

			if(empty($contactMeta['bin_contact_first_name'][0]))
			{
				update_post_meta($post_id, 'bin_contact_first_name', sanitize_text_field($postdata['first_name']));
			}

			if(empty($contactMeta['bin_contact_last_name'][0]))
			{
				update_post_meta($post_id, 'bin_contact_last_name', sanitize_text_field($postdata['last_name']));
			}

			if(empty($contactMeta['bin_contact_designation'][0]))
			{
				update_post_meta($post_id, 'bin_contact_designation', sanitize_text_field($postdata['designation']));
			}

			if(empty($contactMeta['bin_contact_mobile'][0]))
			{
				update_post_meta($post_id, 'bin_contact_mobile', sanitize_text_field($postdata['mobile']));
			}

			if(empty($contactMeta['bin_contact_phone_private'][0]))
			{
				update_post_meta($post_id, 'bin_contact_phone_private', sanitize_text_field($postdata['phone_private']));
			}

			if(empty($contactMeta['bin_contact_phone_work'][0]))
			{
				update_post_meta($post_id, 'bin_contact_phone_work', sanitize_text_field($postdata['phone_work']));
			}

			if(empty($contactMeta['bin_contact_street_and_number'][0]))
			{
				update_post_meta($post_id, 'bin_contact_street_and_number', sanitize_text_field($postdata['street_and_number']));
			}

			if(empty($contactMeta['bin_contact_zip'][0]))
			{
				update_post_meta($post_id, 'bin_contact_zip', sanitize_text_field($postdata['zip']));
			}

			if(empty($contactMeta['bin_contact_city'][0]))
			{
				update_post_meta($post_id, 'bin_contact_city', sanitize_text_field($postdata['city']));
			}

			if(empty($contactMeta['bin_contact_country'][0]))
			{
				update_post_meta($post_id, 'bin_contact_country', sanitize_text_field($postdata['country']));
			}

			if(empty($contactMeta['bin_contact_website'][0]))
			{
				update_post_meta($post_id, 'bin_contact_website', sanitize_text_field($postdata['website']));
			}

			if(empty($contactMeta['bin_contact_facebook'][0]))
			{
				update_post_meta($post_id, 'bin_contact_facebook', sanitize_text_field($postdata['facebook']));
			}

			if(empty($contactMeta['bin_contact_twitter'][0]))
			{
				update_post_meta($post_id, 'bin_contact_twitter', sanitize_text_field($postdata['twitter']));
			}

			if(empty($contactMeta['bin_contact_instagram'][0]))
			{
				update_post_meta($post_id, 'bin_contact_instagram', sanitize_text_field($postdata['instagram']));
			}

			if(empty($contactMeta['bin_contact_flickr'][0]))
			{
				update_post_meta($post_id, 'bin_contact_flickr', sanitize_text_field($postdata['flickr']));
			}

			if(empty($contactMeta['bin_contact_linkedin'][0]))
			{
				update_post_meta($post_id, 'bin_contact_linkedin', sanitize_text_field($postdata['linkedin']));
			}

			if(empty($contactMeta['bin_contact_xing'][0]))
			{
				update_post_meta($post_id, 'bin_contact_xing', sanitize_text_field($postdata['xing']));
			}

			if(empty($contactMeta['bin_contact_youtube'][0]))
			{
				update_post_meta($post_id, 'bin_contact_youtube', sanitize_text_field($postdata['youtube']));
			}
			
			if(empty($contactMeta['bin_contact_socialmedia_other1'][0]))
			{
				update_post_meta($post_id, 'bin_contact_socialmedia_other1', sanitize_text_field($postdata['socialmedia_other1']));
			}
			
			if(empty($contactMeta['bin_contact_socialmedia_other2'][0]))
			{
				update_post_meta($post_id, 'bin_contact_socialmedia_other2', sanitize_text_field($postdata['socialmedia_other2']));
			}
			
			if(empty($contactMeta['bin_contact_socialmedia_other3'][0]))
			{
				update_post_meta($post_id, 'bin_contact_socialmedia_other3', sanitize_text_field($postdata['socialmedia_other3']));
			}

			if(empty($contactMeta['bin_contact_terms_and_conditions_accepted'][0]))
			{
				update_post_meta($post_id, 'bin_contact_terms_and_conditions_accepted', sanitize_text_field($postdata['terms_and_conditions_accepted']));
			}
			
			if(empty($contactMeta['bin_contact_privacy_policy_accepted'][0]))
			{
				update_post_meta($post_id, 'bin_contact_privacy_policy_accepted', sanitize_text_field($postdata['privacy_policy_accepted']));
			}
			
			if($contactMeta['bin_opt_in_contact'][0] === 'unregistered' || empty($contactMeta['bin_opt_in_contact'][0]))
			{
				update_post_meta($post_id, 'bin_opt_in_contact', sanitize_text_field($bin_opt_in_contact));
				update_post_meta($post_id, 'bin_opt_in_contact_opt_in_admin_message', sanitize_text_field($opt_in_admin_message));
				update_post_meta($post_id, 'bin_opt_in_contact_double_opt_in', sanitize_text_field($double_opt_in));
				update_post_meta($post_id, 'bin_opt_in_contact_admin_unlock', sanitize_text_field($admin_unlock));
				update_post_meta($post_id, 'bin_opt_in_contact_unlock_message', sanitize_text_field($unlock_message));
			}
		}

		// insert new contact
		else
		{
			$post_id = wp_insert_post([
				'post_title' => sanitize_email($postdata['email']),
				'post_status' => 'publish',
				'post_type' => 'contact',
				'meta_input' => [
					'bin_contact_salutation' => sanitize_text_field($postdata['salutation']),
					'bin_contact_polite_form' => sanitize_text_field($postdata['politeform']),
					'bin_contact_language_of_correspondence' => sanitize_text_field($postdata['language_of_correspondence']),
					'bin_contact_name_suffix' => sanitize_text_field($postdata['name_suffix']),
					'bin_contact_first_name' => sanitize_text_field($postdata['first_name']),
					'bin_contact_last_name' => sanitize_text_field($postdata['last_name']),
					'bin_contact_designation' => sanitize_text_field($postdata['designation']),
					'bin_contact_mobile' => sanitize_text_field($postdata['mobile']),
					'bin_contact_phone_private' => sanitize_text_field($postdata['phone_private']),
					'bin_contact_phone_work' => sanitize_text_field($postdata['phone_work']),
					'bin_contact_street_and_number' => sanitize_text_field($postdata['street_and_number']),
					'bin_contact_zip' => sanitize_text_field($postdata['zip']),
					'bin_contact_city' => sanitize_text_field($postdata['city']),
					'bin_contact_country' => sanitize_text_field($postdata['country']),
					'bin_contact_website' => sanitize_text_field($postdata['website']),
					'bin_contact_facebook' => sanitize_text_field($postdata['facebook']),
					'bin_contact_twitter' => sanitize_text_field($postdata['twitter']),
					'bin_contact_instagram' => sanitize_text_field($postdata['instagram']),
					'bin_contact_flickr' => sanitize_text_field($postdata['flickr']),
					'bin_contact_linkedin' => sanitize_text_field($postdata['linkedin']),
					'bin_contact_xing' => sanitize_text_field($postdata['xing']),
					'bin_contact_youtube' => sanitize_text_field($postdata['youtube']),
					'bin_contact_socialmedia_other1' => sanitize_text_field($postdata['socialmedia_other1']),
					'bin_contact_socialmedia_other2' => sanitize_text_field($postdata['socialmedia_other2']),
					'bin_contact_socialmedia_other3' => sanitize_text_field($postdata['socialmedia_other3']),
					'bin_contact_email' => sanitize_email($postdata['email']),
					'bin_contact_terms_and_conditions_accepted' => sanitize_text_field($postdata['terms_and_conditions_accepted']),
					'bin_contact_privacy_policy_accepted' => sanitize_text_field($postdata['privacy_policy_accepted']),
					'bin_opt_in_contact' => sanitize_text_field($bin_opt_in_contact),
					'bin_opt_in_contact_opt_in_admin_message' => sanitize_text_field($opt_in_admin_message),
					'bin_opt_in_contact_double_opt_in' => sanitize_text_field($double_opt_in),
					'bin_opt_in_contact_admin_unlock' => sanitize_text_field($admin_unlock),
					'bin_opt_in_contact_unlock_message' => sanitize_text_field($unlock_message),
				]
			]);
		}
		
		// add submission link if torro form
		/*if(!empty($form) && !empty($submission))
		{
			$submissionsArray = is_serialized($contactMeta['bin_contact_submission'][0]) ? unserialize($contactMeta['bin_contact_submission'][0]) : [];
			$submissionsArray[] = [
				'submission_id' => $submission->id,
				'form_id' => $submission->form_id,
				'form_name' => $form->post_title,
				'timestamp' => $submission->timestamp
			];

			update_post_meta($post_id, 'bin_contact_submission', $submissionsArray);
		}*/
		
		return $post_id;
	}
	
	public static function sendMessages($postdata, $opt_in_admin_message, $double_opt_in, $admin_unlock, $unlock_message)
	{
		// settings enabled check did before
		if(is_email(sanitize_email($postdata['email'])))
		{
			// send message if someone opt-in
			if($opt_in_admin_message === true)
			{
				self::sendMessageAdminMessage($postdata['first_name'], $postdata['email']);
			}
			
			// send 
			if($double_opt_in === true)
			{
				self::sendMessageDoubleOptIn($postdata['first_name'], $postdata['email']);
			}
			
			// send to the admin to unlock the entry
			else if($admin_unlock === true)
			{
				self::sendMessageAdminUnlock($postdata['first_name'], $postdata['email']);
			}

			// send unlock message to client
			else if($unlock_message === true)
			{
				self::sendMessageUnlockMessage($postdata['first_name'], $postdata['email']);
			}
		}
	}
	
	public static function sendMessageAdminMessage($name, $email)
	{
		$to = sanitize_email(get_option('bin_opt_in_email_receiver_address')) ?: get_option('admin_email');
		$subject = sprintf(__('%s has opt-in', 'bin-opt-in'), (sanitize_text_field($name) ?: sanitize_email($email)));

		$body = '<table border="0" width="100%" cellpadding="0" cellspacing="0">';
			$body .= '<tr>';
				$body .= '<td style="background:none; border-bottom:1px solid {BIN_EMAIL_TEMPLATE_CONTAINER_TEXT_COLOR}; color:{BIN_EMAIL_TEMPLATE_CONTAINER_TEXT_COLOR}; width:100%; margin-top:0px; margin-left:0px; margin-bottom:0px; margin-right:0px;">';
					$body .= '<h1 style="font-size:22px; margin-top:0px; margin-bottom:0px;">'.$subject.'</h1>';
				$body .= '</td>';
			$body .= '</tr>';
		$body .= '</table>';

		$body .= '<p>';
			$body .= __('Go to your WordPress dashboard to manage your contacts.', 'bin-opt-in').'<br>';
			$body .= '<a href="http://nebs.undefiniert.ch/wp-admin/edit.php?post_type=contact">'.__('Open my dashboard', 'bin-opt-in').'</a>';
		$body .= '</p>';

		self::mail($to, $subject, $body);
	}
	
	public static function sendMessageDoubleOptIn($name, $email)
	{
		$to = sanitize_email($email);
		$subject = sprintf(__('%s, please confirm your subscription', 'bin-opt-in'), (sanitize_text_field($name) ?: sanitize_email($email)));

		$body = '<table border="0" width="100%" cellpadding="0" cellspacing="0">';
			$body .= '<tr>';
				$body .= '<td style="background:none; border-bottom:1px solid {BIN_EMAIL_TEMPLATE_CONTAINER_TEXT_COLOR}; color:{BIN_EMAIL_TEMPLATE_CONTAINER_TEXT_COLOR}; width:100%; margin-top:0px; margin-left:0px; margin-bottom:0px; margin-right:0px;">';
					$body .= '<h1 style="font-size:22px; margin-top:0px; margin-bottom:0px;">'.$subject.'</h1>';
				$body .= '</td>';
			$body .= '</tr>';
		$body .= '</table>';

		$body .= '<p>';
			$body .= __('Just click the link and you\'re done.', 'bin-opt-in').'<br>';
			$body .= '<a href="'.get_site_url().'/opt-in/confirm?a='.base64_encode('action=opt-in&email='.sanitize_email($email).'&unlock=false').'">'.__('Click here to confirm your email', 'bin-opt-in').'</a>';
		$body .= '</p>';

		self::mail($to, $subject, $body);
	}
	
	public static function sendMessageAdminUnlock($name, $email)
	{
		$to = sanitize_email(get_option('bin_opt_in_email_receiver_address')) ?: get_option('admin_email');
		$subject = __('Congrats, someone has opt-in', 'bin-opt-in');

		$body = '<table border="0" width="100%" cellpadding="0" cellspacing="0">';
			$body .= '<tr>';
				$body .= '<td style="background:none; border-bottom:1px solid {BIN_EMAIL_TEMPLATE_CONTAINER_TEXT_COLOR}; color:{BIN_EMAIL_TEMPLATE_CONTAINER_TEXT_COLOR}; width:100%; margin-top:0px; margin-left:0px; margin-bottom:0px; margin-right:0px;">';
					$body .= '<h1 style="font-size:22px; margin-top:0px; margin-bottom:0px;">'.$subject.'</h1>';
				$body .= '</td>';
			$body .= '</tr>';
		$body .= '</table>';

		$body .= '<p>';
			$body .= sprintf(__('%s with email %s has opt-in. Please confirm now.', 'bin-opt-in'), sanitize_text_field($name), sanitize_email($email)).'<br>';
			$body .= '<a href="'.get_site_url().'/opt-in/confirm?a='.base64_encode('action=opt-in&email='.sanitize_email($email).'&unlock=false').'">'.__('Click here to confirm your email', 'bin-opt-in').'</a>';
		$body .= '</p>';

		self::mail($to, $subject, $body);
	}
	
	public static function sendMessageUnlockMessage($name, $email)
	{
		// send info to the client
		$to = sanitize_email($email);
		$subject = sprintf(__('Hi %s, thanks for opt-in', 'bin-opt-in'), (sanitize_text_field($name) ?: sanitize_email($email)));

		$body = '<table border="0" width="100%" cellpadding="0" cellspacing="0">';
			$body .= '<tr>';
				$body .= '<td style="background:none; border-bottom:1px solid {BIN_EMAIL_TEMPLATE_CONTAINER_TEXT_COLOR}; color:{BIN_EMAIL_TEMPLATE_CONTAINER_TEXT_COLOR}; width:100%; margin-top:0px; margin-left:0px; margin-bottom:0px; margin-right:0px;">';
					$body .= '<h1 style="font-size:22px; margin-top:0px; margin-bottom:0px;">'.$subject.'</h1>';
				$body .= '</td>';
			$body .= '</tr>';
		$body .= '</table>';

		$body .= '<p>'.__('Thank you for opt-in. Your entry has just been unlocked by the site owner.', 'bin-opt-in').'</p>';

		self::mail($to, $subject, $body);
	}
	
	/**
	 * Wrap WP Mail
	 */
	public static function mail($to, $subject, $body, $template = 'emptyFooter.html', $attachments = '')
	{
		$headers = [];
		$fromName = get_option('bin_opt_in_email_sender_name') ?: 'WordPress';
		$fromMail = get_option('bin_opt_in_email_sender_address') ?: get_option('admin_email');
			
		$headers[] = 'Content-Type: text/html; charset=UTF-8';
		$headers[] = 'From: '.$fromName.' <'.$fromMail.'>';
			
		if(file_exists(BIN_OPT_IN_DIR.'/messages/'.$template))
		{
			$tpl = file_get_contents(BIN_OPT_IN_DIR.'/messages/'.$template);
			$body = self::prepare_mailbody($tpl, $body);
		}
			
		wp_mail($to, $subject, $body, $headers, $attachments);
	}
	
	/**
	 * Prepare mail and add template
	 * @param type $tpl
	 * @param type $body
	 * @return type
	 */
	public static function prepare_mailbody($tpl, $body)
	{
		// extract body if string contains complete html document
		preg_match("/<body[^>]*>(.*?)<\/body>/is", $body, $matches);
		if(isset($matches[1]))
		{
			$body = $matches[1];
		}
		else
		{
			// if not contain html
			BinOptInBinOptIn_UrlLinker::init();
			$body = preg_replace("/\<((https|http)(.*))\>/", "$2$3", $body);		// remove <> plain link surrounding
			$body = nl2br($body);													// nl2br
			$body = BinOptInBinOptIn_UrlLinker::linkUrlsInTrustedHtml($body);						// autolink
		}

		// parse placeholder
		$tpl = str_replace('{BODY}', $body, $tpl);
		$tpl = str_replace('{FOOTER}', __('Log in to the website and change the message settings if you no longer wish to receive this type of notifications.'), $tpl);
		$tpl = str_replace('{BIN_OPT_IN}', sprintf(__('<a href="%s" style="color:inherit; text-decoration:underline;">%s</a>', 'bin-opt-in'), (get_option('bin_opt_in_email_template_brand_url') ?: 'https://berginformatik.ch'), (get_option('bin_opt_in_email_template_brand_name') ?: 'Berg Informatik')), $tpl);
		$tpl = str_replace('{BIN_EMAIL_TEMPLATE_LOGO}', (get_option('bin_opt_in_email_template_logo') ? '<img src="'.get_option('bin_opt_in_email_template_logo').'" alt="header" border="0">' : ''), $tpl);
		$tpl = str_replace('{BIN_EMAIL_TEMPLATE_BACKGROUND_COLOR}', (get_option('bin_opt_in_email_template_background_color') ?: '#ffffff'), $tpl);
		$tpl = str_replace('{BIN_EMAIL_TEMPLATE_FOOTER_TEXT_COLOR}', (get_option('bin_opt_in_email_template_footer_text_color') ?: '#888888'), $tpl);
		$tpl = str_replace('{BIN_EMAIL_TEMPLATE_CONTAINER_TEXT_COLOR}', (get_option('bin_opt_in_email_template_container_text_color') ?: '#555555'), $tpl);
		$tpl = str_replace('{BIN_EMAIL_TEMPLATE_CONTAINER_BACKGROUND_COLOR}', (get_option('bin_opt_in_email_template_container_background_color') ?: '#ededed'), $tpl);
		
		// get all img tags
		preg_match_all('/<img[^>]*src="([^"]*)"/i', $tpl, $matches);
		if(isset($matches[0]))
		{
			// embed images
			foreach($matches[0] as $index => $img)
			{
				$src = $matches[1][$index];

				if(preg_match("/\.jpg/", $src))
				{
					$dataType = "image/jpg";
				}
				elseif(preg_match("/\.png/", $src))
				{
					$dataType = "image/jpg";
				}
				elseif(preg_match("/\.gif/", $src))
				{
					$dataType = "image/gif";
				}

				if($dataType)
				{
					$urlContent = file_get_contents($src);
					$tpl = str_replace($src, 'data:'.$dataType.';base64,'.base64_encode($urlContent), $tpl);
				}
			}
		}
		
		return $tpl;
	}
	
	/*
	 * default options
	 */
	private static function options()
	{
		return [
			'bin_opt_in_email_receiver_address' => '',
			'bin_opt_in_email_template_logo' => '',
			'bin_opt_in_email_template_background_color' => '',
			'bin_opt_in_email_template_footer_text_color' => '',
			'bin_opt_in_email_template_container_background_color' => '',
			'bin_opt_in_email_template_container_text_color' => '',
			'bin_opt_in_dependency_check' => 'enabled',
			'bin_opt_in_email_template_brand_name' => '',
			'bin_opt_in_email_template_brand_url' => '',
		];
	}
	
	/**
	 * fires on activate plugin
	 * add initial options to settings page
	 * register schedule events
	 */
	public static function activate()
	{
		global $wp_rewrite;
		self::init_custompages();
		$wp_rewrite->flush_rules(false);
		
		foreach(self::options() as $option => $value)
		{
			if(!get_option($option))
			{
				add_option($option, $value);
			}
		}
    }
	
	/**
	 * fires on deactivate plugin
	 * unregister schedule events
	 */
	public static function deactivate()
	{
		//self::uninstall();
	}
	
	/**
	 * fires on uninstall plugin
	 * delete options
	 */
	public static function uninstall()
	{
		foreach(self::options() as $option => $value)
		{
			delete_option($option);
		}
	}
}